%define anolis_release 1

Summary:         Library to enable creation and expansion of ISO-9660 filesystems
Name:            libisoburn
Version:         1.5.4
Release:         %{anolis_release}%{?dist}
License:         GPLv2+
URL:             https://libburnia-project.org/
Source0:         https://files.libburnia-project.org/releases/%{name}-%{version}.tar.gz
Patch0:          libisoburn-1.5.4-rpath.patch

BuildRequires:   gcc, gcc-c++, make, readline-devel, libacl-devel, zlib-devel
BuildRequires:   libburn-devel >= %{version}
BuildRequires:   libisofs-devel >= %{version}

%description
Libisoburn is a front-end for libraries libburn and libisofs which
enables creation and expansion of ISO-9660 filesystems on all CD/
DVD/BD media supported by libburn. This includes media like DVD+RW,
which do not support multi-session management on media level and
even plain disk files or block devices. Price for that is thorough
specialization on data files in ISO-9660 filesystem images. And so
libisoburn is not suitable for audio (CD-DA) or any other CD layout
which does not entirely consist of ISO-9660 sessions.

%package devel
Summary:         Development files for %{name}
Requires:        %{name} = %{version}-%{release}

%description devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%package doc
Summary:         Documentation files for %{name}
BuildArch:       noarch
BuildRequires:   doxygen, graphviz

%description doc
Libisoburn is a front-end for libraries libburn and libisofs which
enables creation and expansion of ISO-9660 filesystems on all CD/
DVD/BD media supported by libburn. And this package contains the API
documentation for developing applications that use %{name}.

%package -n xorriso
Summary:         ISO-9660 and Rock Ridge image manipulation tool
URL:             http://scdbackup.sourceforge.net/xorriso_eng.html
Requires:        %{name} = %{version}-%{release}
Requires(post):  %{_sbindir}/alternatives, coreutils
Requires(preun): %{_sbindir}/alternatives

%description -n xorriso
Xorriso is a program which copies file objects from POSIX compliant
filesystems into Rock Ridge enhanced ISO-9660 filesystems and allows
session-wise manipulation of such filesystems. It can load management
information of existing ISO images and it writes the session results
to optical media or to filesystem objects. Vice versa xorriso is able
to copy file objects out of ISO-9660 filesystems.

Filesystem manipulation capabilities surpass those of mkisofs. Xorriso
is especially suitable for backups, because of its high fidelity of
file attribute recording and its incremental update sessions. Optical
supported media: CD-R, CD-RW, DVD-R, DVD-RW, DVD+R, DVD+R DL, DVD+RW,
DVD-RAM, BD-R and BD-RE.

%prep
%autosetup -p1 -n %{name}-%{version}

%build
%configure --disable-static
%make_build
doxygen doc/doxygen.conf

%install
%make_install

# Clean up for later usage in documentation
rm -rf $RPM_BUILD_ROOT%{_defaultdocdir}

# Prepare alternatives handling for cdrecord -> xorrecord and mkisofs -> xorriso
touch $RPM_BUILD_ROOT{%{_bindir}/{cdrecord,mkisofs},%{_mandir}/man1/{cdrecord,mkisofs}.1.zst}

# Don't ship proof of concept for the moment
rm -f $RPM_BUILD_ROOT{%{_bindir},%{_infodir},%{_mandir}/man1}/xorriso-tcltk*

%generate_compatibility_deps

%check
export LD_LIBRARY_PATH="$LD_LIBRARY_PATH:$RPM_BUILD_ROOT%{_libdir}"
cd releng
./run_all_auto -x ../xorriso/xorriso || (cat releng_generated_data/log.*; exit 1)

%post -n xorriso
%{_sbindir}/alternatives --install %{_bindir}/cdrecord cdrecord %{_bindir}/xorrecord 50 \
  --slave %{_mandir}/man1/cdrecord.1.zst cdrecord-cdrecordman %{_mandir}/man1/xorrecord.1.zst
%{_sbindir}/alternatives --install %{_bindir}/mkisofs mkisofs %{_bindir}/xorrisofs 50 \
  --slave %{_mandir}/man1/mkisofs.1.zst mkisofs-mkisofsman %{_mandir}/man1/xorrisofs.1.zst

%preun -n xorriso
if [ $1 -eq 0 ]; then
  %{_sbindir}/alternatives --remove cdrecord %{_bindir}/xorrecord
  %{_sbindir}/alternatives --remove mkisofs %{_bindir}/xorrisofs
fi

%files
%license COPYING COPYRIGHT
%{_libdir}/%{name}*.so.*
%dir %{abidir}
%{abidir}/*.dump

%files devel
%{_includedir}/%{name}
%{_libdir}/%{name}.so
%{_libdir}/pkgconfig/%{name}*.pc

%files doc
%doc doc/html/
%doc AUTHORS README ChangeLog

%files -n xorriso
%ghost %{_bindir}/cdrecord
%ghost %{_bindir}/mkisofs
%{_bindir}/osirrox
%{_bindir}/xorrecord
%{_bindir}/xorriso
%{_bindir}/xorrisofs
%{_bindir}/xorriso-dd-target
%ghost %{_mandir}/man1/cdrecord.1*
%ghost %{_mandir}/man1/mkisofs.1*
%{_mandir}/man1/xorrecord.1*
%{_mandir}/man1/xorriso.1*
%{_mandir}/man1/xorrisofs.1*
%{_mandir}/man1/xorriso-dd-target.1*
%{_infodir}/xorrecord.info*
%{_infodir}/xorriso.info*
%{_infodir}/xorrisofs.info*
%{_infodir}/xorriso-dd-target.info*
%{abidir}/*-option.list

%changelog
* Wed Mar 15 2023 Chunmei Xu <xuchunmei@linux.alibaba.com> - 1.5.4-1
- init from upstream
